/**
 * @file
 * JS extensions for comment_plus_js module.
 */

// Create our own namespace and specialized functions.
Drupal.commentPlusJs = {

  /**
   * Make an Ajax request to the module callbacks.
   *
   * @param caller
   */
  ajaxRequest: function(caller) {
    var cid = Drupal.commentPlusJs.extractId(caller, 'cid');
    var url = Drupal.settings.commentPlusJs.callbackPath + Drupal.commentPlusJs.extractId(caller, 'nid') + '/' + cid;
    $.ajax({
      type: 'POST',
      dataType: 'json',
      url: Drupal.settings.basePath + url,
      success: function(data) {
        Drupal.commentPlusJs.updateForm(cid, data);
      }
    });
  },

  /**
   * Extract the nid/cid from a link's CSS class.
   */
  extractId: function(caller, type) {
    var ret = '';
    var regex = new RegExp('\\bcomment-plus-reply-' + type + '-([0-9]+)');
    var ids = caller.attr('class').match(regex);
    if (ids) {
      ret = ids[1];
    }
    return ret;
  },

  /**
   * Change form data on successful Ajax operation.
   *
   * This callback processes instant reply results.
   * It changes the comment form's subject and body to the data
   * retrieved from the server callback.
   *
   * It also changes the form's "referer" field which will help
   * to properly indicate which content the new comment refers to.
   * This is important as the comment form, when residing on the node page
   * below the node and it's comments, by default considers comments always
   * referring to the node itself whyle the user may have clicked "reply to
   * comment".
   */
  updateForm: function(cid, data) {
    if (data) {
      if (data.subject != '') {
        $('input#edit-subject').val(data.subject);
      }

      // WYSIWYG support. Inspired by http://drupal.org/project/comment_easy_reply.
      var textareaid = 'edit-comment';
      var focused = false;
      if (Drupal.wysiwyg && Drupal.wysiwyg.activeId && $('textarea#edit-comment').css('display') == 'none') {
        // setContent() method has been added very late to wysiwyg API.
        // To remedy this for older versions, we rather append the content
        // than risking an exception.
        if (typeof Drupal.wysiwyg.instances[Drupal.wysiwyg.activeId].setContent != 'function') {
          Drupal.wysiwyg.instances[Drupal.wysiwyg.activeId].insert(data.content);
        }
        else {
          Drupal.wysiwyg.instances[Drupal.wysiwyg.activeId].setContent(data.content);
        }
      }
      // CKeditor module support.
      else if (typeof(CKEDITOR) != 'undefined' && CKEDITOR.instances[textareaid] && $('textarea#edit-comment').css('display') == 'none') {
        CKEDITOR.instances[textareaid].setData(data.content);
      }
      // TinyMCE module support.
      else if (typeof(tinyMCE) != 'undefined' && tinyMCE.activeEditor && $('textarea#edit-comment').css('display') == 'none') {
        tinyMCE.activeEditor.execCommand('mceSetContent', false, data.content);
      }
      // FCKeditor module support.
      else if (typeof(FCKeditorAPI) != 'undefined' && typeof(fckActiveId) != 'undefined' && $('textarea#edit-comment').css('display') == 'none') {
        FCKeditorAPI.Instances[fckActiveId].setHTML(data.content);
      }
      // No editor found, go for plain textarea.
      else {
        $('textarea#edit-comment').val(data.content).scrollTop(
          $("textarea#edit-comment").attr("scrollHeight")
        ).focus();
        focused = true;
      }
      // Focus the editor.
      if (!focused) {
        $('div#edit-comment-wrapper').scrollTop($('div#edit-comment-wrapper').attr("scrollHeight"));
      }
      $('input#edit-pid').val(cid);
    }
  }
}

Drupal.behaviors.commentPlusJs = function(context) {

  // Create dynamic links and attach events. This all will only work
  // if we have the comment form residing on the same page, of course.
  if ($('form#comment-form').length > 0) {

    // Instant reply links.
    if (Drupal.settings.commentPlusJs.instantReplies) {
      $("a.comment-plus-js-reply, ", context).each(function() {
        $(this).click(function(event) {
          $('p#comment-form-replacement').hide();
          $('form#comment-form').show();
          Drupal.commentPlusJs.ajaxRequest($(this));
          event.preventDefault();
        });
      });
    }

    // Hide form if configured.
    if (Drupal.settings.commentPlusJs.hideForm) {
      $('form#comment-form', context).hide().before(
        '<p id="comment-form-replacement">' + Drupal.settings.commentPlusJs.formReplacementText + '</p>'
      );
    }
  }
}
